# AFFIPred: AlphaFold based Functional Impact Prediction of Missense Variations

## Usage:
First, install the tool using pip.
```
pip install -i https://test.pypi.org/simple/ affipred==0.0.2
```

Provide input and output files relative or absolute path:
```
affipred_pred variants.vcf -o affipred_results.csv
```
